import loremIpsum from 'lorem-ipsum'
import uuidv5 from 'uuid'
import generateName from 'sillyname'
import coolImages from 'cool-images'

class FakeHeadline {
    initialize() {
        return loremIpsum({
            count: 1, 
            units: 'sentences',
            sentenceUpperBound: 7
        })
    }
}

class FakeDescription {
    initialize() {
        return loremIpsum({
            count: 3, 
            units: 'sentences',
            sentenceUpperBound: 20
        })
    }
}

class FakeSection {
    initialize() {
        return loremIpsum({
            count: 1, 
            units: 'words',
            words: ['News', 'Politics', 'Sports', 'Lifestyle', 'Entertainment', 'Rural Living' ]
        })
    }
}

function getRandomInt(min, max) {
    min = Math.ceil(min);
    max = Math.floor(max);
    return Math.floor(Math.random() * (max - min)) + min;
  }

class FakeAuthors {
    initialize() {
        const rand = getRandomInt(1, 2)
        const authors = []

        for (let i = 0; i < rand; i++) {
            authors.push({
                name: generateName(),
                _id: uuidv5()
            })
        }

        return authors;
    }
}

class ANSStory {
    constructor(options) {
        return { 
            _id: uuidv5(),
            canonical_url: 'https://www.washingtonpost.com',
            headlines: {
                basic: new FakeHeadline().initialize()
            },
            description: {
                basic: new FakeDescription().initialize()
            },
            websites: {
                washingtonPost: {
                    website_section: new FakeSection().initialize()
                }
            },
            credits: {
                by: new FakeAuthors().initialize()
            },
            promo_items: {
                basic: {
                    _id: uuidv5(),
                    type: 'image',
                    url: coolImages.one()
                }
            }
        }
    }
}

// This is an array of ANS Stories, mocked up with only relevant fields included.

const mockFeed = []

const numberOfStoriesInFeed = getRandomInt(1, 2)

for (let i = 0; i < numberOfStoriesInFeed; i++) {
    mockFeed.push(new ANSStory())
}

export default mockFeed